@@ -5,8 +5,11 @@
 macro_rules! coercible_trait {
     ($trait:path) => {
         unsafe impl $crate::container::Coercible for dyn $trait {
-            type Coerced<U: 'static + ?Sized> = U;
+            type Coerced<U: 'static + ?::core::marker::Sized> = U;
             type Innermost = Self;
+        }
+
+        unsafe impl $crate::container::InnermostTypeId for dyn $trait {
             fn innermost_type_id(&self) -> ::core::any::TypeId {
                 ::core::any::Any::type_id(self)
             }
@@ -16,7 +19,41 @@ macro_rules! coercible_trait {
 
 macro_rules! coercibles {
     (<$lt:lifetime, $x:ident, $u:ident>($self:ident) {
-        $(#[$feature:literal])? $ty:ty => $coerced:ty $body:block,
+        $(#[$feature:literal])? $ty:ty => $coerced:ty,
+        $($rest:tt)*
+    }) => {
+        coercibles! {
+            <$lt, $x, $u>($self) {
+                $(#[$feature])? $ty => $coerced { (**$self).innermost_type_id() }, $($rest)*
+            }
+        }
+    };
+    (<$lt:lifetime, $x:ident, $u:ident>($self:ident) {
+        $(#[$feature:literal])? $ty:ty => $coerced:ty { $($token:tt)+ },
+        $($rest:tt)*
+    }) => {
+        $(
+            #[cfg(any(feature = $feature, doc))]
+            #[doc(cfg(feature = $feature))]
+        )?
+        unsafe impl<$lt, $x> $crate::container::InnermostTypeId for $ty
+        where
+            $x: ?::core::marker::Sized + $crate::container::InnermostTypeId,
+        {
+            fn innermost_type_id(&$self) -> ::core::any::TypeId {
+                $($token)+
+            }
+        }
+
+        coercibles! {
+            <$lt, $x, $u>($self) {
+                $(#[$feature])? $ty => $coerced {},
+                $($rest)*
+            }
+        }
+    };
+    (<$lt:lifetime, $x:ident, $u:ident>($self:ident) {
+        $(#[$feature:literal])? $ty:ty => $coerced:ty {},
         $($rest:tt)*
     }) => {
         $(
@@ -29,7 +66,6 @@ macro_rules! coercibles {
         {
             type Coerced<$u: 'static + ?::core::marker::Sized> = $coerced;
             type Innermost = $x::Innermost;
-            fn innermost_type_id(&$self) -> ::core::any::TypeId $body
         }
 
         coercibles! {
@@ -38,16 +74,6 @@ macro_rules! coercibles {
             }
         }
     };
-    (<$lt:lifetime, $x:ident, $u:ident>($self:ident) {
-        $(#[$feature:literal])? $ty:ty => $coerced:ty,
-        $($rest:tt)*
-    }) => {
-        coercibles! {
-            <$lt, $x, $u>($self) {
-                $(#[$feature])? $ty => $coerced { (**$self).innermost_type_id() }, $($rest)*
-            }
-        }
-    };
     (<$lt:lifetime, $x:ident, $u:ident>($self:ident) {}) => {};
 }
 
@@ -65,10 +91,12 @@ macro_rules! pointers {
         where
             $x: ?::core::marker::Sized + $crate::container::Coercible,
         {
+            type Target = $x;
+
             unsafe fn coerce<U>($self, $metadata: $crate::container::Metadata<$crate::container::Coerced<Self::Target, U>>) -> Self::Coerced<U>
             where
-                U: ?Sized,
-                Self::Coerced<U>: Sized,
+                U: ?::core::marker::Sized,
+                Self::Coerced<U>: ::core::marker::Sized,
             $body
         }
     )+)+};
