@@ -24,7 +24,6 @@ impl<U> Default for HashMapTypeDatabaseEntry<U>
 where
     U: ?Sized,
 {
-    #[inline(always)]
     fn default() -> Self {
         HashMapTypeDatabaseEntry(Default::default())
     }
@@ -46,12 +45,13 @@ macro_rules! rtti {
     }};
 }
 
-/// An immutable, thread-safe [`HashMapTypeDatabase`].
+/// A global, immutable, thread-safe [`HashMapTypeDatabase`] that can be
+/// initialized with [`rtti_static`].
 #[cfg(any(feature = "static", doc))]
 #[doc(cfg(feature = "static"))]
 pub static DB: SyncOnceCell<HashMapTypeDatabase> = SyncOnceCell::new();
 
-/// Instantiates [`DB`] with the provided entries.
+/// Instantiates the global [`DB`] with the provided entries.
 #[macro_export]
 #[cfg(any(feature = "static", doc))]
 #[doc(cfg(feature = "static"))]
@@ -61,28 +61,23 @@ macro_rules! rtti_static {
     }};
 }
 
-#[doc(cfg(feature = "std"))]
 unsafe impl<U> TypeDatabaseEntry<U> for HashMapTypeDatabaseEntry<U>
 where
     U: ?Sized,
 {
-    #[inline(always)]
     unsafe fn add(&mut self, type_id: TypeId, metadata: Metadata<U>) {
         self.0.insert(type_id, metadata);
     }
 
-    #[inline(always)]
     fn contains<'a>(&self, type_id: TypeId) -> bool {
         self.0.contains_key(&type_id)
     }
 
-    #[inline(always)]
     fn metadata(&self, type_id: TypeId) -> Option<&Metadata<U>> {
         self.0.get(&type_id)
     }
 }
 
-#[doc(cfg(feature = "std"))]
 unsafe impl TypeDatabase for HashMapTypeDatabase {
     type Entry<U: ?Sized> = HashMapTypeDatabaseEntry<U>;
 
@@ -97,7 +92,6 @@ unsafe impl TypeDatabase for HashMapTypeDatabase {
             .unwrap()
     }
 
-    #[inline(always)]
     fn get_entry<U>(&self) -> Option<&Self::Entry<U>>
     where
         U: 'static + ?Sized,
